@@ -13,16 +13,15 @@
 # limitations under the License.
 
 """Transport classes for Python logging integration.
-
 Currently two options are provided, a synchronous transport that makes
 an API call for each log statement, and an asynchronous handler that
 sends the API using a :class:`~google.cloud.logging.logger.Batch` object in
 the background.
 """
 
-from google.cloud.logging.handlers.transports.base import Transport
-from google.cloud.logging.handlers.transports.sync import SyncTransport
-from google.cloud.logging.handlers.transports.background_thread import (
+from google.cloud.logging_v2.handlers.transports.base import Transport
+from google.cloud.logging_v2.handlers.transports.sync import SyncTransport
+from google.cloud.logging_v2.handlers.transports.background_thread import (
     BackgroundThreadTransport,
 )
 
