@@ -14,10 +14,10 @@
 
 import time
 import logging
+import queue
 import unittest
 
 import mock
-from six.moves import queue
 
 
 class TestBackgroundThreadHandler(unittest.TestCase):
@@ -31,7 +31,7 @@ class TestBackgroundThreadHandler(unittest.TestCase):
 
     def _make_one(self, *args, **kw):
         worker_patch = mock.patch(
-            "google.cloud.logging.handlers.transports." "background_thread._Worker",
+            "google.cloud.logging_v2.handlers.transports." "background_thread._Worker",
             autospec=True,
         )
         with worker_patch as worker_mock:
@@ -47,7 +47,7 @@ class TestBackgroundThreadHandler(unittest.TestCase):
         self.assertEqual(logger.name, name)
 
     def test_send(self):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         client = _Client(self.PROJECT)
         name = "python_logger"
@@ -61,14 +61,39 @@ class TestBackgroundThreadHandler(unittest.TestCase):
             python_logger_name, logging.INFO, None, None, message, None, None
         )
 
-        transport.send(record, message, _GLOBAL_RESOURCE)
+        transport.send(record, message, resource=_GLOBAL_RESOURCE)
 
         transport.worker.enqueue.assert_called_once_with(
-            record, message, _GLOBAL_RESOURCE, None, trace=None, span_id=None
+            record,
+            message,
+            resource=_GLOBAL_RESOURCE,
+        )
+
+    def test_send_json(self):
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
+
+        client = _Client(self.PROJECT)
+        name = "python_logger"
+
+        transport, _ = self._make_one(client, name)
+
+        python_logger_name = "mylogger"
+        message = {"hello": {"world": "!"}}
+
+        record = logging.LogRecord(
+            python_logger_name, logging.INFO, None, None, message, None, None
+        )
+
+        transport.send(record, message, resource=_GLOBAL_RESOURCE)
+
+        transport.worker.enqueue.assert_called_once_with(
+            record,
+            message,
+            resource=_GLOBAL_RESOURCE,
         )
 
     def test_trace_send(self):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         client = _Client(self.PROJECT)
         name = "python_logger"
@@ -83,14 +108,17 @@ class TestBackgroundThreadHandler(unittest.TestCase):
             python_logger_name, logging.INFO, None, None, message, None, None
         )
 
-        transport.send(record, message, _GLOBAL_RESOURCE, trace=trace)
+        transport.send(record, message, resource=_GLOBAL_RESOURCE, trace=trace)
 
         transport.worker.enqueue.assert_called_once_with(
-            record, message, _GLOBAL_RESOURCE, None, trace=trace, span_id=None
+            record,
+            message,
+            resource=_GLOBAL_RESOURCE,
+            trace=trace,
         )
 
     def test_span_send(self):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         client = _Client(self.PROJECT)
         name = "python_logger"
@@ -105,10 +133,13 @@ class TestBackgroundThreadHandler(unittest.TestCase):
             python_logger_name, logging.INFO, None, None, message, None, None
         )
 
-        transport.send(record, message, _GLOBAL_RESOURCE, span_id=span_id)
+        transport.send(record, message, resource=_GLOBAL_RESOURCE, span_id=span_id)
 
         transport.worker.enqueue.assert_called_once_with(
-            record, message, _GLOBAL_RESOURCE, None, trace=None, span_id=span_id
+            record,
+            message,
+            resource=_GLOBAL_RESOURCE,
+            span_id=span_id,
         )
 
     def test_flush(self):
@@ -147,7 +178,7 @@ class Test_Worker(unittest.TestCase):
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         return background_thread._Worker
 
@@ -181,7 +212,7 @@ class Test_Worker(unittest.TestCase):
         self.assertIsNone(worker._thread)
 
     def test_start(self):
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         worker = self._make_one(_Logger(self.NAME))
 
@@ -200,7 +231,7 @@ class Test_Worker(unittest.TestCase):
         self.assertIs(current_thread, worker._thread)
 
     def test_stop(self):
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         grace_period = 5.0
         worker = self._make_one(_Logger(self.NAME))
@@ -208,7 +239,7 @@ class Test_Worker(unittest.TestCase):
         self._start_with_thread_patch(worker)
         thread = worker._thread
 
-        worker.stop(grace_period)
+        worker.stop(grace_period=grace_period)
 
         self.assertEqual(worker._queue.qsize(), 1)
         self.assertEqual(worker._queue.get(), background_thread._WORKER_TERMINATOR)
@@ -270,7 +301,7 @@ class Test_Worker(unittest.TestCase):
 
     def test_enqueue_defaults(self):
         import datetime
-        from google.cloud.logging._helpers import LogSeverity
+        from google.cloud.logging_v2._helpers import LogSeverity
 
         worker = self._make_one(_Logger(self.NAME))
         self.assertTrue(worker._queue.empty())
@@ -279,18 +310,18 @@ class Test_Worker(unittest.TestCase):
         self._enqueue_record(worker, message)
 
         entry = worker._queue.get_nowait()
-        expected_info = {"message": message, "python_logger": "testing"}
-        self.assertEqual(entry["info"], expected_info)
+        self.assertEqual(entry["message"], message)
         self.assertEqual(entry["severity"], LogSeverity.INFO)
-        self.assertIsNone(entry["resource"])
-        self.assertIsNone(entry["labels"])
-        self.assertIsNone(entry["trace"])
-        self.assertIsNone(entry["span_id"])
         self.assertIsInstance(entry["timestamp"], datetime.datetime)
+        self.assertNotIn("resource", entry.keys())
+        self.assertNotIn("trace", entry.keys())
+        self.assertNotIn("span_id", entry.keys())
+        self.assertNotIn("http_request", entry.keys())
+        self.assertEqual(entry["labels"], {"python_logger": "testing"})
 
     def test_enqueue_explicit(self):
         import datetime
-        from google.cloud.logging._helpers import LogSeverity
+        from google.cloud.logging_v2._helpers import LogSeverity
 
         worker = self._make_one(_Logger(self.NAME))
         self.assertTrue(worker._queue.empty())
@@ -312,17 +343,16 @@ class Test_Worker(unittest.TestCase):
 
         entry = worker._queue.get_nowait()
 
-        expected_info = {"message": message, "python_logger": "testing"}
-        self.assertEqual(entry["info"], expected_info)
+        self.assertEqual(entry["message"], message)
         self.assertEqual(entry["severity"], LogSeverity.ERROR)
         self.assertIs(entry["resource"], resource)
-        self.assertIs(entry["labels"], labels)
+        self.assertEqual(entry["labels"], {**labels, "python_logger": "testing"})
         self.assertIs(entry["trace"], trace)
         self.assertIs(entry["span_id"], span_id)
         self.assertIsInstance(entry["timestamp"], datetime.datetime)
 
     def test__thread_main(self):
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         worker = self._make_one(_Logger(self.NAME))
 
@@ -338,7 +368,7 @@ class Test_Worker(unittest.TestCase):
         self.assertEqual(worker._queue.qsize(), 0)
 
     def test__thread_main_error(self):
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         worker = self._make_one(_Logger(self.NAME))
         worker._cloud_logger._batch_cls = _RaisingBatch
@@ -353,7 +383,7 @@ class Test_Worker(unittest.TestCase):
         self.assertEqual(worker._queue.qsize(), 0)
 
     def test__thread_main_batches(self):
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         worker = self._make_one(_Logger(self.NAME), max_batch_size=2)
 
@@ -378,8 +408,7 @@ class Test_Worker(unittest.TestCase):
         # _get_many invokes queue.get() followed by queue._get(). It fails
         # the "change detector" test in that way. However, this is still a
         # useful test to verify the queue timeout is appropriately calculated.
-        from six.moves import queue
-        from google.cloud.logging.handlers.transports import background_thread
+        from google.cloud.logging_v2.handlers.transports import background_thread
 
         # Use monotonically increasing time.
         time.side_effect = range(1, 6)
@@ -388,9 +417,9 @@ class Test_Worker(unittest.TestCase):
         worker._queue = mock.create_autospec(queue.Queue, instance=True)
 
         worker._queue.get.side_effect = [
-            {"info": {"message": "1"}},  # Single record.
+            {"message": 1},  # Single record.
             queue.Empty(),  # Emulate a queue.get() timeout.
-            {"info": {"message": "1"}},  # Second record.
+            {"message": "2"},  # Second record.
             background_thread._WORKER_TERMINATOR,  # Stop the thread.
             queue.Empty(),  # Emulate a queue.get() timeout.
         ]
@@ -479,23 +508,24 @@ class _Batch(object):
         self.commit_called = False
         self.commit_count = None
 
-    def log_struct(
+    def log(
         self,
-        info,
+        message,
         severity=logging.INFO,
         resource=None,
         labels=None,
         trace=None,
         span_id=None,
         timestamp=None,
+        http_request=None,
     ):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         assert resource is None
         resource = _GLOBAL_RESOURCE
 
-        self.log_struct_called_with = (info, severity, resource, labels, trace, span_id)
-        self.entries.append(info)
+        self.log_called_with = (message, severity, resource, labels, trace, span_id)
+        self.entries.append(message)
 
     def commit(self):
         self.commit_called = True
@@ -510,11 +540,12 @@ class _RaisingBatch(_Batch):
 
 
 class _Logger(object):
-    def __init__(self, name):
+    def __init__(self, name, resource=None):
         self.name = name
         self._batch_cls = _Batch
         self._batch = None
         self._num_batches = 0
+        self.resource = resource
 
     def batch(self):
         self._batch = self._batch_cls()
@@ -531,6 +562,6 @@ class _Client(object):
         self._credentials = credentials
         self._connection = mock.Mock(credentials=credentials, spec=["credentials"])
 
-    def logger(self, name):  # pylint: disable=unused-argument
-        self._logger = _Logger(name)
+    def logger(self, name, resource=None):  # pylint: disable=unused-argument
+        self._logger = _Logger(name, resource=resource)
         return self._logger
