@@ -24,19 +24,18 @@ def _make_credentials():
 
 
 class TestConnection(unittest.TestCase):
-
     PROJECT = "project"
     FILTER = "logName:syslog AND severity>=ERROR"
 
     @staticmethod
     def _get_default_timeout():
-        from google.cloud.logging._http import _http
+        from google.cloud.logging_v2._http import _http
 
         return _http._DEFAULT_TIMEOUT
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging._http import Connection
+        from google.cloud.logging_v2._http import Connection
 
         return Connection
 
@@ -49,8 +48,8 @@ class TestConnection(unittest.TestCase):
         self.assertIs(conn._client, client)
 
     def test_build_api_url_w_custom_endpoint(self):
-        from six.moves.urllib.parse import parse_qsl
-        from six.moves.urllib.parse import urlsplit
+        from urllib.parse import parse_qsl
+        from urllib.parse import urlsplit
 
         custom_endpoint = "https://foo-logging.googleapis.com"
         conn = self._make_one(object(), api_endpoint=custom_endpoint)
@@ -96,16 +95,17 @@ class TestConnection(unittest.TestCase):
 
 
 class Test_LoggingAPI(unittest.TestCase):
-
     PROJECT = "project"
+    PROJECT_PATH = "projects/project"
     LIST_ENTRIES_PATH = "entries:list"
     WRITE_ENTRIES_PATH = "entries:write"
     LOGGER_NAME = "LOGGER_NAME"
+    LOGGER_PATH = "projects/project/logs/LOGGER_NAME"
     FILTER = "logName:syslog AND severity>=ERROR"
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging._http import _LoggingAPI
+        from google.cloud.logging_v2._http import _LoggingAPI
 
         return _LoggingAPI
 
@@ -122,22 +122,25 @@ class Test_LoggingAPI(unittest.TestCase):
     @staticmethod
     def _make_timestamp():
         import datetime
-        from google.cloud._helpers import UTC
+        from datetime import timezone
 
-        NOW = datetime.datetime.utcnow().replace(tzinfo=UTC)
+        NOW = datetime.datetime.now(timezone.utc)
         return NOW, _datetime_to_rfc3339_w_nanos(NOW)
 
-    def test_list_entries_no_paging(self):
-        import six
-        from google.cloud.logging.client import Client
-        from google.cloud.logging.entries import TextEntry
-        from google.cloud.logging.logger import Logger
+    def test_list_entries_with_limits(self):
+        from google.cloud.logging import Client
+        from google.cloud.logging import TextEntry
+        from google.cloud.logging import Logger
 
         NOW, TIMESTAMP = self._make_timestamp()
         IID = "IID"
+        IID1 = "IID1"
+        IID2 = "IID2"
         TEXT = "TEXT"
-        SENT = {"projectIds": [self.PROJECT]}
-        TOKEN = "TOKEN"
+        SENT = {"resourceNames": [self.PROJECT_PATH]}
+        PAYLOAD = {"message": "MESSAGE", "weather": "partly cloudy"}
+        PROTO_PAYLOAD = PAYLOAD.copy()
+        PROTO_PAYLOAD["@type"] = "type.googleapis.com/testing.example"
         RETURNED = {
             "entries": [
                 {
@@ -145,25 +148,43 @@ class Test_LoggingAPI(unittest.TestCase):
                     "insertId": IID,
                     "resource": {"type": "global"},
                     "timestamp": TIMESTAMP,
+                    "logName": f"projects/{self.PROJECT}/logs/{self.LOGGER_NAME}",
+                },
+                {
+                    "jsonPayload": PAYLOAD,
+                    "insertId": IID1,
+                    "resource": {"type": "global"},
+                    "timestamp": TIMESTAMP,
                     "logName": "projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME),
-                }
+                },
+                {
+                    "protoPayload": PROTO_PAYLOAD,
+                    "insertId": IID2,
+                    "resource": {"type": "global"},
+                    "timestamp": TIMESTAMP,
+                    "logName": "projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME),
+                },
             ],
-            "nextPageToken": TOKEN,
         }
         client = Client(
             project=self.PROJECT, credentials=_make_credentials(), _use_grpc=False
         )
+        # try with negative max_results
+        with self.assertRaises(ValueError):
+            client._connection = _Connection(RETURNED)
+            api = self._make_one(client)
+            empty = list(api.list_entries([self.PROJECT_PATH], max_results=-1))
+        # try with max_results of 0
         client._connection = _Connection(RETURNED)
         api = self._make_one(client)
-
-        iterator = api.list_entries([self.PROJECT])
-        page = six.next(iterator.pages)
-        entries = list(page)
-        token = iterator.next_page_token
-
-        # First check the token.
-        self.assertEqual(token, TOKEN)
-        # Then check the entries returned.
+        empty = list(api.list_entries([self.PROJECT_PATH], max_results=0))
+        self.assertEqual(empty, [])
+        # try with single result
+        client._connection = _Connection(RETURNED)
+        api = self._make_one(client)
+        iterator = api.list_entries([self.PROJECT_PATH], max_results=1)
+        entries = list(iterator)
+        # check the entries returned.
         self.assertEqual(len(entries), 1)
         entry = entries[0]
         self.assertIsInstance(entry, TextEntry)
@@ -182,15 +203,17 @@ class Test_LoggingAPI(unittest.TestCase):
             called_with, {"method": "POST", "path": expected_path, "data": SENT}
         )
 
-    def test_list_entries_w_paging(self):
+    def test_list_entries(self):
         from google.cloud.logging import DESCENDING
-        from google.cloud.logging.client import Client
-        from google.cloud.logging.logger import Logger
-        from google.cloud.logging.entries import ProtobufEntry
-        from google.cloud.logging.entries import StructEntry
+        from google.cloud.logging import Client
+        from google.cloud.logging import Logger
+        from google.cloud.logging import ProtobufEntry
+        from google.cloud.logging import StructEntry
 
         PROJECT1 = "PROJECT1"
+        PROJECT1_PATH = f"projects/{PROJECT1}"
         PROJECT2 = "PROJECT2"
+        PROJECT2_PATH = f"projects/{PROJECT2}"
         NOW, TIMESTAMP = self._make_timestamp()
         IID1 = "IID1"
         IID2 = "IID2"
@@ -200,7 +223,7 @@ class Test_LoggingAPI(unittest.TestCase):
         TOKEN = "TOKEN"
         PAGE_SIZE = 42
         SENT = {
-            "projectIds": [PROJECT1, PROJECT2],
+            "resourceNames": [PROJECT1_PATH, PROJECT2_PATH],
             "filter": self.FILTER,
             "orderBy": DESCENDING,
             "pageSize": PAGE_SIZE,
@@ -231,18 +254,15 @@ class Test_LoggingAPI(unittest.TestCase):
         api = self._make_one(client)
 
         iterator = api.list_entries(
-            projects=[PROJECT1, PROJECT2],
+            resource_names=[PROJECT1_PATH, PROJECT2_PATH],
             filter_=self.FILTER,
             order_by=DESCENDING,
             page_size=PAGE_SIZE,
             page_token=TOKEN,
         )
         entries = list(iterator)
-        token = iterator.next_page_token
 
-        # First check the token.
-        self.assertIsNone(token)
-        # Then check the entries returned.
+        # Check the entries returned.
         self.assertEqual(len(entries), 2)
         entry1 = entries[0]
         self.assertIsInstance(entry1, StructEntry)
@@ -277,23 +297,23 @@ class Test_LoggingAPI(unittest.TestCase):
         ENTRY = {
             "textPayload": TEXT,
             "resource": {"type": "global"},
-            "logName": "projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME),
+            "logName": "projects/{self.PROJECT}/logs/{self.LOGGER_NAME}",
         }
-        SENT = {"entries": [ENTRY]}
+        SENT = {"entries": [ENTRY], "partialSuccess": False, "dry_run": False}
         conn = _Connection({})
         client = _Client(conn)
         api = self._make_one(client)
 
-        api.write_entries([ENTRY])
+        api.write_entries([ENTRY], partial_success=False)
 
         self.assertEqual(conn._called_with["method"], "POST")
-        path = "/%s" % self.WRITE_ENTRIES_PATH
+        path = f"/{self.WRITE_ENTRIES_PATH}"
         self.assertEqual(conn._called_with["path"], path)
         self.assertEqual(conn._called_with["data"], SENT)
 
     def test_write_entries_multiple(self):
         TEXT = "TEXT"
-        LOG_NAME = "projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME)
+        LOG_NAME = f"projects/{self.PROJECT}/logs/{self.LOGGER_NAME}"
         RESOURCE = {"type": "global"}
         LABELS = {"baz": "qux", "spam": "eggs"}
         ENTRY1 = {"textPayload": TEXT}
@@ -303,43 +323,47 @@ class Test_LoggingAPI(unittest.TestCase):
             "resource": RESOURCE,
             "labels": LABELS,
             "entries": [ENTRY1, ENTRY2],
+            "partialSuccess": True,
+            "dry_run": False,
         }
         conn = _Connection({})
         client = _Client(conn)
         api = self._make_one(client)
 
-        api.write_entries([ENTRY1, ENTRY2], LOG_NAME, RESOURCE, LABELS)
+        api.write_entries(
+            [ENTRY1, ENTRY2], logger_name=LOG_NAME, resource=RESOURCE, labels=LABELS
+        )
 
         self.assertEqual(conn._called_with["method"], "POST")
-        path = "/%s" % self.WRITE_ENTRIES_PATH
+        path = f"/{self.WRITE_ENTRIES_PATH}"
         self.assertEqual(conn._called_with["path"], path)
         self.assertEqual(conn._called_with["data"], SENT)
 
     def test_logger_delete(self):
-        path = "/projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME)
+        path = f"/projects/{self.PROJECT}/logs/{self.LOGGER_NAME}"
         conn = _Connection({})
         client = _Client(conn)
         api = self._make_one(client)
 
-        api.logger_delete(self.PROJECT, self.LOGGER_NAME)
+        api.logger_delete(self.LOGGER_PATH)
 
         self.assertEqual(conn._called_with["method"], "DELETE")
         self.assertEqual(conn._called_with["path"], path)
 
 
 class Test_SinksAPI(unittest.TestCase):
-
     PROJECT = "project"
+    PROJECT_PATH = "projects/project"
     FILTER = "logName:syslog AND severity>=ERROR"
-    LIST_SINKS_PATH = "projects/%s/sinks" % (PROJECT,)
+    LIST_SINKS_PATH = f"projects/{PROJECT}/sinks"
     SINK_NAME = "sink_name"
-    SINK_PATH = "projects/%s/sinks/%s" % (PROJECT, SINK_NAME)
+    SINK_PATH = f"projects/{PROJECT}/sinks/{SINK_NAME}"
     DESTINATION_URI = "faux.googleapis.com/destination"
     WRITER_IDENTITY = "serviceAccount:project-123@example.com"
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging._http import _SinksAPI
+        from google.cloud.logging_v2._http import _SinksAPI
 
         return _SinksAPI
 
@@ -353,33 +377,38 @@ class Test_SinksAPI(unittest.TestCase):
         self.assertIs(api._client, client)
         self.assertEqual(api.api_request, connection.api_request)
 
-    def test_list_sinks_no_paging(self):
-        import six
-        from google.cloud.logging.sink import Sink
+    def test_list_sinks_max_returned(self):
+        from google.cloud.logging import Sink
 
-        TOKEN = "TOKEN"
         RETURNED = {
             "sinks": [
                 {
                     "name": self.SINK_PATH,
                     "filter": self.FILTER,
                     "destination": self.DESTINATION_URI,
-                }
+                },
+                {"name": "test", "filter": "test", "destination": "test"},
             ],
-            "nextPageToken": TOKEN,
         }
+        # try with negative max_results
+        with self.assertRaises(ValueError):
+            conn = _Connection(RETURNED)
+            client = _Client(conn)
+            api = self._make_one(client)
+            empty = list(api.list_sinks(self.PROJECT_PATH, max_results=-1))
+        # try with max_results of 0
         conn = _Connection(RETURNED)
         client = _Client(conn)
         api = self._make_one(client)
-
-        iterator = api.list_sinks(self.PROJECT)
-        page = six.next(iterator.pages)
-        sinks = list(page)
-        token = iterator.next_page_token
-
-        # First check the token.
-        self.assertEqual(token, TOKEN)
-        # Then check the sinks returned.
+        empty = list(api.list_sinks(self.PROJECT_PATH, max_results=0))
+        self.assertEqual(empty, [])
+        # try with single result
+        conn = _Connection(RETURNED)
+        client = _Client(conn)
+        api = self._make_one(client)
+        iterator = api.list_sinks(self.PROJECT_PATH, max_results=1)
+        sinks = list(iterator)
+        # Check the sinks returned.
         self.assertEqual(len(sinks), 1)
         sink = sinks[0]
         self.assertIsInstance(sink, Sink)
@@ -389,13 +418,13 @@ class Test_SinksAPI(unittest.TestCase):
         self.assertIs(sink.client, client)
 
         called_with = conn._called_with
-        path = "/%s" % (self.LIST_SINKS_PATH,)
+        path = f"/{self.LIST_SINKS_PATH}"
         self.assertEqual(
             called_with, {"method": "GET", "path": path, "query_params": {}}
         )
 
-    def test_list_sinks_w_paging(self):
-        from google.cloud.logging.sink import Sink
+    def test_list_sinks(self):
+        from google.cloud.logging import Sink
 
         TOKEN = "TOKEN"
         PAGE_SIZE = 42
@@ -412,13 +441,11 @@ class Test_SinksAPI(unittest.TestCase):
         client = _Client(conn)
         api = self._make_one(client)
 
-        iterator = api.list_sinks(self.PROJECT, page_size=PAGE_SIZE, page_token=TOKEN)
+        iterator = api.list_sinks(
+            self.PROJECT_PATH, page_size=PAGE_SIZE, page_token=TOKEN
+        )
         sinks = list(iterator)
-        token = iterator.next_page_token
-
-        # First check the token.
-        self.assertIsNone(token)
-        # Then check the sinks returned.
+        # Check the sinks returned.
         self.assertEqual(len(sinks), 1)
         sink = sinks[0]
         self.assertIsInstance(sink, Sink)
@@ -428,7 +455,7 @@ class Test_SinksAPI(unittest.TestCase):
         self.assertIs(sink.client, client)
 
         called_with = conn._called_with
-        path = "/%s" % (self.LIST_SINKS_PATH,)
+        path = f"/{self.LIST_SINKS_PATH}"
         self.assertEqual(
             called_with,
             {
@@ -453,10 +480,10 @@ class Test_SinksAPI(unittest.TestCase):
 
         with self.assertRaises(Conflict):
             api.sink_create(
-                self.PROJECT, self.SINK_NAME, self.FILTER, self.DESTINATION_URI
+                self.PROJECT_PATH, self.SINK_NAME, self.FILTER, self.DESTINATION_URI
             )
 
-        path = "/projects/%s/sinks" % (self.PROJECT,)
+        path = f"/projects/{self.PROJECT}/sinks"
         expected = {
             "method": "POST",
             "path": path,
@@ -478,7 +505,7 @@ class Test_SinksAPI(unittest.TestCase):
         api = self._make_one(client)
 
         returned = api.sink_create(
-            self.PROJECT,
+            self.PROJECT_PATH,
             self.SINK_NAME,
             self.FILTER,
             self.DESTINATION_URI,
@@ -486,7 +513,7 @@ class Test_SinksAPI(unittest.TestCase):
         )
 
         self.assertEqual(returned, after_create)
-        path = "/projects/%s/sinks" % (self.PROJECT,)
+        path = f"/projects/{self.PROJECT}/sinks"
         expected = {
             "method": "POST",
             "path": path,
@@ -503,10 +530,10 @@ class Test_SinksAPI(unittest.TestCase):
         api = self._make_one(client)
 
         with self.assertRaises(NotFound):
-            api.sink_get(self.PROJECT, self.SINK_NAME)
+            api.sink_get(self.SINK_PATH)
 
         self.assertEqual(conn._called_with["method"], "GET")
-        path = "/projects/%s/sinks/%s" % (self.PROJECT, self.SINK_NAME)
+        path = f"/projects/{self.PROJECT}/sinks/{self.SINK_NAME}"
         self.assertEqual(conn._called_with["path"], path)
 
     def test_sink_get_hit(self):
@@ -519,11 +546,11 @@ class Test_SinksAPI(unittest.TestCase):
         client = _Client(conn)
         api = self._make_one(client)
 
-        response = api.sink_get(self.PROJECT, self.SINK_NAME)
+        response = api.sink_get(self.SINK_PATH)
 
         self.assertEqual(response, RESPONSE)
         self.assertEqual(conn._called_with["method"], "GET")
-        path = "/projects/%s/sinks/%s" % (self.PROJECT, self.SINK_NAME)
+        path = f"/projects/{self.PROJECT}/sinks/{self.SINK_NAME}"
         self.assertEqual(conn._called_with["path"], path)
 
     def test_sink_update_miss(self):
@@ -539,11 +566,9 @@ class Test_SinksAPI(unittest.TestCase):
         api = self._make_one(client)
 
         with self.assertRaises(NotFound):
-            api.sink_update(
-                self.PROJECT, self.SINK_NAME, self.FILTER, self.DESTINATION_URI
-            )
+            api.sink_update(self.SINK_PATH, self.FILTER, self.DESTINATION_URI)
 
-        path = "/projects/%s/sinks/%s" % (self.PROJECT, self.SINK_NAME)
+        path = f"/projects/{self.PROJECT}/sinks/{self.SINK_NAME}"
         expected = {
             "method": "PUT",
             "path": path,
@@ -565,15 +590,14 @@ class Test_SinksAPI(unittest.TestCase):
         api = self._make_one(client)
 
         returned = api.sink_update(
-            self.PROJECT,
-            self.SINK_NAME,
+            self.SINK_PATH,
             self.FILTER,
             self.DESTINATION_URI,
             unique_writer_identity=True,
         )
 
         self.assertEqual(returned, after_update)
-        path = "/projects/%s/sinks/%s" % (self.PROJECT, self.SINK_NAME)
+        path = f"/projects/{self.PROJECT}/sinks/{self.SINK_NAME}"
         expected = {
             "method": "PUT",
             "path": path,
@@ -590,10 +614,10 @@ class Test_SinksAPI(unittest.TestCase):
         api = self._make_one(client)
 
         with self.assertRaises(NotFound):
-            api.sink_delete(self.PROJECT, self.SINK_NAME)
+            api.sink_delete(self.SINK_PATH)
 
         self.assertEqual(conn._called_with["method"], "DELETE")
-        path = "/projects/%s/sinks/%s" % (self.PROJECT, self.SINK_NAME)
+        path = f"/projects/{self.PROJECT}/sinks/{self.SINK_NAME}"
         self.assertEqual(conn._called_with["path"], path)
 
     def test_sink_delete_hit(self):
@@ -601,15 +625,14 @@ class Test_SinksAPI(unittest.TestCase):
         client = _Client(conn)
         api = self._make_one(client)
 
-        api.sink_delete(self.PROJECT, self.SINK_NAME)
+        api.sink_delete(self.SINK_PATH)
 
         self.assertEqual(conn._called_with["method"], "DELETE")
-        path = "/projects/%s/sinks/%s" % (self.PROJECT, self.SINK_NAME)
+        path = f"/projects/{self.PROJECT}/sinks/{self.SINK_NAME}"
         self.assertEqual(conn._called_with["path"], path)
 
 
 class Test_MetricsAPI(unittest.TestCase):
-
     PROJECT = "project"
     FILTER = "logName:syslog AND severity>=ERROR"
     LIST_METRICS_PATH = "projects/%s/metrics" % (PROJECT,)
@@ -619,34 +642,42 @@ class Test_MetricsAPI(unittest.TestCase):
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging._http import _MetricsAPI
+        from google.cloud.logging_v2._http import _MetricsAPI
 
         return _MetricsAPI
 
     def _make_one(self, *args, **kw):
         return self._get_target_class()(*args, **kw)
 
-    def test_list_metrics_no_paging(self):
-        import six
-        from google.cloud.logging.metric import Metric
+    def test_list_metrics_max_results(self):
+        from google.cloud.logging import Metric
 
-        TOKEN = "TOKEN"
         RETURNED = {
-            "metrics": [{"name": self.METRIC_PATH, "filter": self.FILTER}],
-            "nextPageToken": TOKEN,
+            "metrics": [
+                {"name": self.METRIC_PATH, "filter": self.FILTER},
+                {"name": "test", "filter": "test"},
+            ],
         }
+        # try with negative max_results
+        with self.assertRaises(ValueError):
+            conn = _Connection(RETURNED)
+            client = _Client(conn)
+            api = self._make_one(client)
+            empty = list(api.list_metrics(self.PROJECT, max_results=-1))
+        # try with max_results of 0
+        conn = _Connection(RETURNED)
+        client = _Client(conn)
+        api = self._make_one(client)
+        empty = list(api.list_metrics(self.PROJECT, max_results=0))
+        self.assertEqual(empty, [])
+        # try with single result
         conn = _Connection(RETURNED)
         client = _Client(conn)
         api = self._make_one(client)
 
-        iterator = api.list_metrics(self.PROJECT)
-        page = six.next(iterator.pages)
-        metrics = list(page)
-        token = iterator.next_page_token
-
-        # First check the token.
-        self.assertEqual(token, TOKEN)
-        # Then check the metrics returned.
+        iterator = api.list_metrics(self.PROJECT, max_results=1)
+        metrics = list(iterator)
+        # Check the metrics returned.
         self.assertEqual(len(metrics), 1)
         metric = metrics[0]
         self.assertIsInstance(metric, Metric)
@@ -661,8 +692,8 @@ class Test_MetricsAPI(unittest.TestCase):
             called_with, {"method": "GET", "path": path, "query_params": {}}
         )
 
-    def test_list_metrics_w_paging(self):
-        from google.cloud.logging.metric import Metric
+    def test_list_metrics(self):
+        from google.cloud.logging import Metric
 
         TOKEN = "TOKEN"
         PAGE_SIZE = 42
@@ -673,11 +704,7 @@ class Test_MetricsAPI(unittest.TestCase):
 
         iterator = api.list_metrics(self.PROJECT, page_size=PAGE_SIZE, page_token=TOKEN)
         metrics = list(iterator)
-        token = iterator.next_page_token
-
-        # First check the token.
-        self.assertIsNone(token)
-        # Then check the metrics returned.
+        # Check the metrics returned.
         self.assertEqual(len(metrics), 1)
         metric = metrics[0]
         self.assertIsInstance(metric, Metric)
@@ -834,7 +861,6 @@ class Test_MetricsAPI(unittest.TestCase):
 
 
 class _Connection(object):
-
     _called_with = None
     _raise_conflict = False
 
