@@ -18,10 +18,10 @@ import mock
 
 
 class Test_logger_name_from_path(unittest.TestCase):
-    def _call_fut(self, path):
-        from google.cloud.logging.entries import logger_name_from_path
+    def _call_fut(self, path, project=None):
+        from google.cloud.logging_v2.entries import logger_name_from_path
 
-        return logger_name_from_path(path)
+        return logger_name_from_path(path, project)
 
     def test_w_simple_name(self):
         LOGGER_NAME = "LOGGER_NAME"
@@ -37,10 +37,34 @@ class Test_logger_name_from_path(unittest.TestCase):
         logger_name = self._call_fut(PATH)
         self.assertEqual(logger_name, LOGGER_NAME)
 
+    def test_w_wrong_project(self):
+        LOGGER_NAME = "LOGGER_NAME"
+        IN_PROJECT = "in-project"
+        PATH_PROJECT = "path-project"
+        PATH = "projects/%s/logs/%s" % (PATH_PROJECT, LOGGER_NAME)
+        with self.assertRaises(ValueError):
+            self._call_fut(PATH, IN_PROJECT)
+
+    def test_invalid_inputs(self):
+        invalid_list = [
+            "",
+            "abc/123/logs/456",
+            "projects//logs/",
+            "projects/123/logs",
+            "projects/123logs/",
+            "projects123/logs",
+            "project/123",
+            "projects123logs456",
+            "/logs/123",
+        ]
+        for path in invalid_list:
+            with self.assertRaises(ValueError):
+                self._call_fut(path)
+
 
 class Test__int_or_none(unittest.TestCase):
     def _call_fut(self, value):
-        from google.cloud.logging.entries import _int_or_none
+        from google.cloud.logging_v2.entries import _int_or_none
 
         return _int_or_none(value)
 
@@ -55,13 +79,12 @@ class Test__int_or_none(unittest.TestCase):
 
 
 class TestLogEntry(unittest.TestCase):
-
     PROJECT = "PROJECT"
     LOGGER_NAME = "LOGGER_NAME"
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging.entries import LogEntry
+        from google.cloud.logging import LogEntry
 
         return LogEntry
 
@@ -69,7 +92,7 @@ class TestLogEntry(unittest.TestCase):
         return self._get_target_class()(*args, **kw)
 
     def test_ctor_defaults(self):
-        from google.cloud.logging.entries import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.entries import _GLOBAL_RESOURCE
 
         entry = self._make_one()
 
@@ -90,7 +113,7 @@ class TestLogEntry(unittest.TestCase):
 
     def test_ctor_explicit(self):
         import datetime
-        from google.cloud.logging.resource import Resource
+        from google.cloud.logging import Resource
 
         LOG_NAME = "projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME)
         IID = "IID"
@@ -177,14 +200,14 @@ class TestLogEntry(unittest.TestCase):
 
     def test_from_api_repr_w_loggers_no_logger_match(self):
         from datetime import datetime
-        from google.cloud._helpers import UTC
-        from google.cloud.logging.resource import Resource
+        from datetime import timezone
+        from google.cloud.logging import Resource
 
         klass = self._get_target_class()
         client = _Client(self.PROJECT)
         SEVERITY = "CRITICAL"
         IID = "IID"
-        NOW = datetime.utcnow().replace(tzinfo=UTC)
+        NOW = datetime.now(timezone.utc)
         TIMESTAMP = _datetime_to_rfc3339_w_nanos(NOW)
         LOG_NAME = "projects/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME)
         LABELS = {"foo": "bar", "baz": "qux"}
@@ -260,11 +283,11 @@ class TestLogEntry(unittest.TestCase):
     def test_from_api_repr_w_loggers_w_logger_match(self):
         from datetime import datetime
         from datetime import timedelta
-        from google.cloud._helpers import UTC
+        from datetime import timezone
 
         client = _Client(self.PROJECT)
         IID = "IID"
-        NOW = datetime.utcnow().replace(tzinfo=UTC)
+        NOW = datetime.now(timezone.utc)
         LATER = NOW + timedelta(seconds=1)
         TIMESTAMP = _datetime_to_rfc3339_w_nanos(NOW)
         RECEIVED = _datetime_to_rfc3339_w_nanos(LATER)
@@ -315,8 +338,64 @@ class TestLogEntry(unittest.TestCase):
         self.assertEqual(entry.operation, OPERATION)
         self.assertIsNone(entry.payload)
 
+    def test_from_api_repr_w_folder_path(self):
+        from datetime import datetime
+        from datetime import timedelta
+        from datetime import timezone
+
+        client = _Client(self.PROJECT)
+        IID = "IID"
+        NOW = datetime.now(timezone.utc)
+        LATER = NOW + timedelta(seconds=1)
+        TIMESTAMP = _datetime_to_rfc3339_w_nanos(NOW)
+        RECEIVED = _datetime_to_rfc3339_w_nanos(LATER)
+        LOG_NAME = "folders/%s/logs/%s" % (self.PROJECT, self.LOGGER_NAME)
+        LABELS = {"foo": "bar", "baz": "qux"}
+        TRACE = "12345678-1234-5678-1234-567812345678"
+        SPANID = "000000000000004a"
+        FILE = "my_file.py"
+        LINE_NO = 123
+        FUNCTION = "my_function"
+        SOURCE_LOCATION = {"file": FILE, "line": str(LINE_NO), "function": FUNCTION}
+        OP_ID = "OP_ID"
+        PRODUCER = "PRODUCER"
+        OPERATION = {"id": OP_ID, "producer": PRODUCER, "first": True, "last": False}
+        API_REPR = {
+            "logName": LOG_NAME,
+            "insertId": IID,
+            "timestamp": TIMESTAMP,
+            "receiveTimestamp": RECEIVED,
+            "labels": LABELS,
+            "trace": TRACE,
+            "spanId": SPANID,
+            "traceSampled": True,
+            "sourceLocation": SOURCE_LOCATION,
+            "operation": OPERATION,
+        }
+        klass = self._get_target_class()
+
+        entry = klass.from_api_repr(API_REPR, client)
+
+        self.assertEqual(entry.log_name, LOG_NAME)
+        self.assertIsNone(entry.logger)
+        self.assertEqual(entry.insert_id, IID)
+        self.assertEqual(entry.timestamp, NOW)
+        self.assertEqual(entry.received_timestamp, LATER)
+        self.assertEqual(entry.labels, LABELS)
+        self.assertEqual(entry.trace, TRACE)
+        self.assertEqual(entry.span_id, SPANID)
+        self.assertTrue(entry.trace_sampled)
+
+        source_location = entry.source_location
+        self.assertEqual(source_location["file"], FILE)
+        self.assertEqual(source_location["line"], LINE_NO)
+        self.assertEqual(source_location["function"], FUNCTION)
+
+        self.assertEqual(entry.operation, OPERATION)
+        self.assertIsNone(entry.payload)
+
     def test_to_api_repr_w_source_location_no_line(self):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         LOG_NAME = "test.log"
         FILE = "my_file.py"
@@ -332,7 +411,7 @@ class TestLogEntry(unittest.TestCase):
 
     def test_to_api_repr_explicit(self):
         import datetime
-        from google.cloud.logging.resource import Resource
+        from google.cloud.logging import Resource
         from google.cloud._helpers import _datetime_to_rfc3339
 
         LOG_NAME = "test.log"
@@ -389,13 +468,12 @@ class TestLogEntry(unittest.TestCase):
 
 
 class TestTextEntry(unittest.TestCase):
-
     PROJECT = "PROJECT"
     LOGGER_NAME = "LOGGER_NAME"
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging.entries import TextEntry
+        from google.cloud.logging import TextEntry
 
         return TextEntry
 
@@ -403,7 +481,7 @@ class TestTextEntry(unittest.TestCase):
         return self._get_target_class()(*args, **kw)
 
     def test_to_api_repr_defaults(self):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         LOG_NAME = "test.log"
         TEXT = "TESTING"
@@ -417,7 +495,7 @@ class TestTextEntry(unittest.TestCase):
 
     def test_to_api_repr_explicit(self):
         import datetime
-        from google.cloud.logging.resource import Resource
+        from google.cloud.logging import Resource
         from google.cloud._helpers import _datetime_to_rfc3339
 
         LOG_NAME = "test.log"
@@ -477,13 +555,12 @@ class TestTextEntry(unittest.TestCase):
 
 
 class TestStructEntry(unittest.TestCase):
-
     PROJECT = "PROJECT"
     LOGGER_NAME = "LOGGER_NAME"
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging.entries import StructEntry
+        from google.cloud.logging import StructEntry
 
         return StructEntry
 
@@ -491,7 +568,7 @@ class TestStructEntry(unittest.TestCase):
         return self._get_target_class()(*args, **kw)
 
     def test_to_api_repr_defaults(self):
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
 
         LOG_NAME = "test.log"
         JSON_PAYLOAD = {"key": "value"}
@@ -503,9 +580,23 @@ class TestStructEntry(unittest.TestCase):
         }
         self.assertEqual(entry.to_api_repr(), expected)
 
+    def test_to_api_repr_struct(self):
+        from google.protobuf.struct_pb2 import Struct, Value
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
+
+        LOG_NAME = "struct.log"
+        message = Struct(fields={"foo": Value(bool_value=True)})
+        entry = self._make_one(log_name=LOG_NAME, payload=message)
+        expected = {
+            "logName": LOG_NAME,
+            "jsonPayload": message,
+            "resource": _GLOBAL_RESOURCE._to_dict(),
+        }
+        self.assertEqual(entry.to_api_repr(), expected)
+
     def test_to_api_repr_explicit(self):
         import datetime
-        from google.cloud.logging.resource import Resource
+        from google.cloud.logging import Resource
         from google.cloud._helpers import _datetime_to_rfc3339
 
         LOG_NAME = "test.log"
@@ -565,13 +656,12 @@ class TestStructEntry(unittest.TestCase):
 
 
 class TestProtobufEntry(unittest.TestCase):
-
     PROJECT = "PROJECT"
     LOGGER_NAME = "LOGGER_NAME"
 
     @staticmethod
     def _get_target_class():
-        from google.cloud.logging.entries import ProtobufEntry
+        from google.cloud.logging import ProtobufEntry
 
         return ProtobufEntry
 
@@ -634,7 +724,7 @@ class TestProtobufEntry(unittest.TestCase):
 
     def test_to_api_repr_proto_defaults(self):
         from google.protobuf.json_format import MessageToDict
-        from google.cloud.logging.logger import _GLOBAL_RESOURCE
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
         from google.protobuf.struct_pb2 import Struct
         from google.protobuf.struct_pb2 import Value
 
@@ -649,10 +739,49 @@ class TestProtobufEntry(unittest.TestCase):
         }
         self.assertEqual(entry.to_api_repr(), expected)
 
+    def test_to_api_repr_proto_inner_struct_field(self):
+        from google.protobuf.json_format import MessageToDict
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
+        from google.protobuf.struct_pb2 import Struct
+        from google.protobuf.struct_pb2 import Value
+
+        LOG_NAME = "test.log"
+        inner_struct = Struct(fields={"foo": Value(string_value="bar")})
+        message = Struct(fields={"inner": Value(struct_value=inner_struct)})
+
+        entry = self._make_one(log_name=LOG_NAME, payload=message)
+        expected = {
+            "logName": LOG_NAME,
+            "protoPayload": MessageToDict(message),
+            "resource": _GLOBAL_RESOURCE._to_dict(),
+        }
+        self.assertEqual(entry.to_api_repr(), expected)
+
+    def test_to_api_repr_proto_inner_list_field(self):
+        from google.protobuf.json_format import MessageToDict
+        from google.cloud.logging_v2.logger import _GLOBAL_RESOURCE
+        from google.protobuf.struct_pb2 import ListValue
+        from google.protobuf.struct_pb2 import Struct
+        from google.protobuf.struct_pb2 import Value
+
+        LOG_NAME = "test.log"
+        lines = ListValue(
+            values=[Value(string_value="line1"), Value(string_value="line2")]
+        )
+        message = Struct(fields={"lines": Value(list_value=lines)})
+
+        entry = self._make_one(log_name=LOG_NAME, payload=message)
+        expected = {
+            "logName": LOG_NAME,
+            "protoPayload": MessageToDict(message),
+            "resource": _GLOBAL_RESOURCE._to_dict(),
+        }
+        self.assertEqual(entry.to_api_repr(), expected)
+
     def test_to_api_repr_proto_explicit(self):
         import datetime
         from google.protobuf.json_format import MessageToDict
-        from google.cloud.logging.resource import Resource
+        from google.cloud.logging import Resource
         from google.cloud._helpers import _datetime_to_rfc3339
         from google.protobuf.struct_pb2 import Struct
         from google.protobuf.struct_pb2 import Value
